# Table of Contents

- [creating-and-editing-diagram-templates](<./creating-and-editing-diagram-templates.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Creating and Editing Diagram Templates](<./Creating-and-Editing-Diagram-Templates.md>)
  - [Overview](<./Creating-and-Editing-Diagram-Templates/Overview.md>)
  - [Creating a Diagram Template](<./Creating-and-Editing-Diagram-Templates/Creating-a-Diagram-Template.md>)
  - [Editing a Diagram Template](<./Creating-and-Editing-Diagram-Templates/Editing-a-Diagram-Template.md>)
  - [Saving and Publishing Templates from the Template Editor](<./Creating-and-Editing-Diagram-Templates/Saving-and-Publishing-Templates-from-the-Template-Editor.md>)
  - [Template Elements at a Glance](<./Creating-and-Editing-Diagram-Templates/Template-Elements-at-a-Glance.md>)
  - [Adding Drill-Downs to a Template](<./Creating-and-Editing-Diagram-Templates/Adding-Drill-Downs-to-a-Template.md>)
  - [Adding Dependencies to a Template](<./Creating-and-Editing-Diagram-Templates/Adding-Dependencies-to-a-Template.md>)
  - [Removing Fact Sheets from a Template](<./Creating-and-Editing-Diagram-Templates/Removing-Fact-Sheets-from-a-Template.md>)
  - [Adding a View to a Template](<./Creating-and-Editing-Diagram-Templates/Adding-a-View-to-a-Template.md>)
  - [Adding Labels to a Template](<./Creating-and-Editing-Diagram-Templates/Adding-Labels-to-a-Template.md>)
  - [Changing Template Layouts](<./Creating-and-Editing-Diagram-Templates/Changing-Template-Layouts.md>)
  - [Publishing and Unpublishing Templates from the Overview Page](<./Creating-and-Editing-Diagram-Templates/Publishing-and-Unpublishing-Templates-from-the-Overview-Page.md>)
